==> unitils-objectvalidation-1.1.1-sources.jar: org/unitils/objectvalidation/objectcreator/generator/CollectionGenerator.java <==
package org.unitils.objectvalidation.objectcreator.generator;

import java.lang.reflect.Array;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.unitils.core.UnitilsException;
import org.unitils.objectvalidation.objectcreator.ObjectCreatorFactory;
import org.unitils.objectvalidation.utils.TreeNode;


/**
 * This generator will take care of interfaces and the classes that have no custom generator.
 * 
 * "Cut this object into pieces this is your last resort! "
 * 
 * @author Jeroen Horemans
 * @since Feb 20, 2012
 */
public class CollectionGenerator implements Generator {

	private static final int MINIMUM = 1;
	private static final int MAXIMUM = 10;
	
    @Override
    public Object generateObject(Class<?> clazz, List<Object> input, List<Class<?>> inputClasses, List<TreeNode> genericSubTypes) throws Exception {

    	if (clazz.isInterface()) {
            
    		if (clazz.isAssignableFrom(Map.class)) {
                
            	if (genericSubTypes == null || genericSubTypes.size() != 2) {
            		throw new UnitilsException("Expected two generic parameters in the hashmap definition.");
            	}

            	Map<Object, Object> hashMap = new HashMap<Object, Object>();
                
            	for (int i = 0; i < numberOfObjectsToGenerate(); i++) {
					
            		
            		Object key =   createRandomObject(genericSubTypes.get(0).getValue());
					Object value = createRandomObject(genericSubTypes.get(1).getValue());
					
					hashMap.put(key, value);
				}
                
				return hashMap;
            }
    		
    		
            if (clazz.isAssignableFrom(List.class)) {

            	if (genericSubTypes == null || genericSubTypes.size() != 1) {
            		throw new UnitilsException("Expected one generic parameters in the List definition.");
            	}
            	
                return createListOf(genericSubTypes);
            }
            if (clazz.isAssignableFrom(Set.class)) {

            	if (genericSubTypes == null || genericSubTypes.size() != 1) {
            		throw new UnitilsException("Expected one generic parameters in the Set definition.");
            	}
                
            	return new HashSet(createListOf(genericSubTypes));
            }
        }

        if (clazz.isArray()) {
        	        	
        	int objectsToGenerate = numberOfObjectsToGenerate();
			Object[] array = (Object[]) Array.newInstance(clazz.getComponentType(), objectsToGenerate);
        	for (int i = 0; i < objectsToGenerate; i++) {
				array[i] = createRandomObject(clazz.getComponentType());
			}
            return array;
        }

        return null;
    }

	private List createListOf(List<TreeNode> genericSubTypes) {
		List list = new ArrayList();
		
		for (int i = 0; i < numberOfObjectsToGenerate(); i++) {
			
			list.add(createRandomObject(genericSubTypes.get(0).getValue()));
		}
		return list;
	}
    
    private <T> T createRandomObject(Class<T> clazz) {
    	return (T) ObjectCreatorFactory.createDefaultObjectCreator().createRandomObject(clazz);
    }
    
    private static int numberOfObjectsToGenerate() {
    	return MINIMUM + (int)(Math.random() * ((MAXIMUM - MINIMUM) + 1));
    }
    
    


}

==> unitils-objectvalidation-1.1.4-sources.jar: org/unitils/objectvalidation/objectcreator/generator/CollectionGenerator.java <==
package org.unitils.objectvalidation.objectcreator.generator;

import java.lang.reflect.Array;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.unitils.core.UnitilsException;
import org.unitils.objectvalidation.objectcreator.ObjectCreatorFactory;
import org.unitils.objectvalidation.utils.TreeNode;


/**
 * This generator will take care of interfaces and the classes that have no custom generator.
 * 
 * "Cut this object into pieces this is your last resort! "
 * 
 * @author Jeroen Horemans
 * @since Feb 20, 2012
 */
public class CollectionGenerator implements Generator {

	private static final int MINIMUM = 1;
	private static final int MAXIMUM = 10;
	
    @SuppressWarnings({
        "unchecked", "rawtypes"
    })
    @Override
    public Object generateObject(Class<?> clazz, List<Object> input, List<Class<?>> inputClasses, List<TreeNode> genericSubTypes) throws Exception {

    	if (clazz.isInterface()) {
            
    		if (clazz.isAssignableFrom(Map.class)) {
                
            	if (genericSubTypes == null || genericSubTypes.size() != 2) {
            		throw new UnitilsException("Expected two generic parameters in the hashmap definition.");
            	}

            	Map<Object, Object> hashMap = new HashMap<Object, Object>();
                
            	for (int i = 0; i < numberOfObjectsToGenerate(); i++) {
					
            		
            		Object key =   createRandomObject(genericSubTypes.get(0).getValue());
					Object value = createRandomObject(genericSubTypes.get(1).getValue());
					
					hashMap.put(key, value);
				}
                
				return hashMap;
            }
    		
    		
            if (clazz.isAssignableFrom(List.class)) {

            	if (genericSubTypes == null || genericSubTypes.size() != 1) {
            		throw new UnitilsException("Expected one generic parameters in the List definition.");
            	}
            	
                return createListOf(genericSubTypes.get(0));
            }
            if (clazz.isAssignableFrom(Set.class)) {

            	if (genericSubTypes == null || genericSubTypes.size() != 1) {
            		throw new UnitilsException("Expected one generic parameters in the Set definition.");
            	}
                
            	return new HashSet(createListOf(genericSubTypes.get(0)));
            }
        }

        if (clazz.isArray()) {
        	        	
            if (genericSubTypes == null || genericSubTypes.size() != 1) {
                throw new UnitilsException("Expected one generic parameters in the array definition.");
            }

            List listOfObjects = createListOf(genericSubTypes.get(0));
            
            Object newInstance = Array.newInstance(genericSubTypes.get(0).getValue(), listOfObjects.size());
            for (int i = 0; i < listOfObjects.size(); i++) {
                
                Array.set(newInstance, i, listOfObjects.get(i));
                
            }
            
            return newInstance;
        }

        return null;
    }

    @SuppressWarnings({
        "unchecked", "rawtypes"
    })
	private List createListOf(TreeNode genericSubTypes) {
		List list = new ArrayList();
		
		for (int i = 0; i < numberOfObjectsToGenerate(); i++) {
			
			list.add(createRandomObject(genericSubTypes.getValue()));
		}
		return list;
	}
    
    @SuppressWarnings("unchecked")
    private <T> T createRandomObject(Class<T> clazz) {
    	return (T) ObjectCreatorFactory.createDefaultObjectCreator().createRandomObject(clazz);
    }
    
    private static int numberOfObjectsToGenerate() {
    	return MINIMUM + (int)(Math.random() * ((MAXIMUM - MINIMUM) + 1));
    }
    
}
